@@ -8,7 +8,7 @@
 #   The Artistic License 2.0 (GPL Compatible)
 #
 package Redis;
-$Redis::VERSION = '1.994';
+$Redis::VERSION = '1.995';
 # ABSTRACT: Perl binding for Redis database
 # VERSION
 # AUTHORITY
@@ -924,7 +924,7 @@ Redis - Perl binding for Redis database
 
 =head1 VERSION
 
-version 1.994
+version 1.995
 
 =head1 SYNOPSIS
 
@@ -1172,7 +1172,7 @@ exception will be thrown.
 
 C<< conservative_reconnect >> option makes sure that reconnection is only attempted
 when no pending command is ongoing. For instance, if you're doing
-C<$redis->incr('key')>, and if the server properly understood and processed the
+C<<$redis->incr('key')>>, and if the server properly understood and processed the
 command, but the network connection is dropped just before the server replies :
 the command has been processed but the client doesn't know it. In this
 situation, if reconnect is enabled, the Redis client will reconnect and send
